/* Last modified: January 20, 2015

*--------------------*
*      OVERVIEW      *
*--------------------*

This Stata code uses the .csv data on state minimum wage changes to prepare two panels of state minimum wage values:

1. As of March 12 annually by state (for use with the BDS)
2. As of the first date of each quarter (Jan. 1, Apr. 1, Jul. 1, and Oct. 1)
3. As of the first date of each month

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

cpiai.txt - from BLS - ftp://ftp.bls.gov/pub/special.requests/cpi/cpiai.txt

state-minimum-wage-changes.csv - prepared by authors - included


*/

*-----------------------------------*
*  PREPARE DAILY PANEL OF STATE MW  *
*-----------------------------------*

insheet using state-minimum-wage-changes.csv , delimit(",") clear

keep if statefips == 0
keep date mw
tostring date , force replace
gen sdate = date(date, "YMD")
drop if sdate < mdy(1,1,1975)
save temp , replace

clear
set obs 1
expand ( mdy(1,1,2013) - mdy(1,1,1975) )
gen sdate = .
replace sdate = mdy(1,1,1975) in 1
replace sdate = sdate[_n-1] + 1 if sdate == .
merge 1:1 sdate using temp
replace mw = mw[_n-1] if mw == .
drop date _merge
rename mw fedmw
save temp , replace

insheet using state-minimum-wage-changes.csv , comma clear
keep statefips
duplicates drop
set obs 52
sort statefips
replace state = 1 in 48 // States that aren't in MW data -- never had one
replace state = 22 in 49
replace state = 28 in 50
replace state = 45 in 51
replace state = 47 in 52
expand ( mdy(1,1,2013) - mdy(1,1,1975) )
gen sdate = .
sort statefips
replace sdate = mdy(1,1,1975) if statefips != statefips[_n-1]
replace sdate = sdate[_n-1] + 1 if sdate == .
save temp1 , replace

insheet using state-minimum-wage-changes.csv , comma clear
keep statefips date mw
tostring date , force replace
gen sdate = date(date, "YMD")

drop if state == 9 & sdate == mdy(1,1,1975) & mw > 2.10 // Correct value is 2.01
drop if state == 9 & sdate == mdy(1,1,1976) & mw > 2.30 // Correct value is 2.21
drop if state == 24 & date == "1976" & mw < 2.21 // Correct value is 2.30

* Correct for early Maryland dates that are tracking Federal anyway
gen temp = date if sdate == .
destring temp , force replace
replace sdate = mdy(1,1,temp) if sdate == .
drop temp

merge 1:1 statefips sdate using temp1
sort statefips sdate
drop _merge
replace mw = mw[_n-1] if sdate <= mdy(1,1,1975) & mw == . & statefips == statefips[_n-1]
drop if sdate > mdy(12,31,2012) | sdate < mdy(1,1,1975)
merge m:1 sdate using temp
sort statefips sdate
drop _merge
replace mw = fedmw if sdate == mdy(1,1,1975) & mw == .
replace mw = fedmw if sdate == mdy(1,1,1975) & mw < fedmw

replace mw = mw[_n-1] if statefips == statefips[_n-1] & mw == .
replace mw = fedmw if mw < fedmw

drop date
sort statefips sdate
compress
erase temp.dta
erase temp1.dta

rename sdate date

drop if year(date) < 1975 | year(date) > 2012

label values statefips fips

*****
*     Define Census Regions, Divisions
*****

gen censusdiv = 0
replace censusdiv = 1 if statefip == 9
replace censusdiv = 1 if statefip == 23
replace censusdiv = 1 if statefip == 25
replace censusdiv = 1 if statefip == 33
replace censusdiv = 1 if statefip == 44
replace censusdiv = 1 if statefip == 50

replace censusdiv = 2 if statefip == 34
replace censusdiv = 2 if statefip == 36
replace censusdiv = 2 if statefip == 42

replace censusdiv = 3 if statefip == 17
replace censusdiv = 3 if statefip == 18
replace censusdiv = 3 if statefip == 26
replace censusdiv = 3 if statefip == 39
replace censusdiv = 3 if statefip == 55

replace censusdiv = 4 if statefip == 19
replace censusdiv = 4 if statefip == 20
replace censusdiv = 4 if statefip == 27
replace censusdiv = 4 if statefip == 29
replace censusdiv = 4 if statefip == 31
replace censusdiv = 4 if statefip == 38
replace censusdiv = 4 if statefip == 46

replace censusdiv = 5 if statefip == 10
replace censusdiv = 5 if statefip == 11
replace censusdiv = 5 if statefip == 12
replace censusdiv = 5 if statefip == 13
replace censusdiv = 5 if statefip == 24
replace censusdiv = 5 if statefip == 37
replace censusdiv = 5 if statefip == 45
replace censusdiv = 5 if statefip == 51
replace censusdiv = 5 if statefip == 54

replace censusdiv = 6 if statefip == 1
replace censusdiv = 6 if statefip == 21
replace censusdiv = 6 if statefip == 28
replace censusdiv = 6 if statefip == 47

replace censusdiv = 7 if statefip == 5
replace censusdiv = 7 if statefip == 22
replace censusdiv = 7 if statefip == 40
replace censusdiv = 7 if statefip == 48

replace censusdiv = 8 if statefip == 4
replace censusdiv = 8 if statefip == 8
replace censusdiv = 8 if statefip == 16
replace censusdiv = 8 if statefip == 30
replace censusdiv = 8 if statefip == 32
replace censusdiv = 8 if statefip == 35
replace censusdiv = 8 if statefip == 49
replace censusdiv = 8 if statefip == 56

replace censusdiv = 9 if statefip == 2
replace censusdiv = 9 if statefip == 6
replace censusdiv = 9 if statefip == 15
replace censusdiv = 9 if statefip == 41
replace censusdiv = 9 if statefip == 53

label variable censusdiv "Census Division (1-9)"

gen censusreg = 0
replace censusreg = 1 if statefip == 9
replace censusreg = 1 if statefip == 23
replace censusreg = 1 if statefip == 25
replace censusreg = 1 if statefip == 33
replace censusreg = 1 if statefip == 44
replace censusreg = 1 if statefip == 50

replace censusreg = 1 if statefip == 34
replace censusreg = 1 if statefip == 36
replace censusreg = 1 if statefip == 42

replace censusreg = 2 if statefip == 17
replace censusreg = 2 if statefip == 18
replace censusreg = 2 if statefip == 26
replace censusreg = 2 if statefip == 39
replace censusreg = 2 if statefip == 55

replace censusreg = 2 if statefip == 19
replace censusreg = 2 if statefip == 20
replace censusreg = 2 if statefip == 27
replace censusreg = 2 if statefip == 29
replace censusreg = 2 if statefip == 31
replace censusreg = 2 if statefip == 38
replace censusreg = 2 if statefip == 46

replace censusreg = 3 if statefip == 10
replace censusreg = 3 if statefip == 11
replace censusreg = 3 if statefip == 12
replace censusreg = 3 if statefip == 13
replace censusreg = 3 if statefip == 24
replace censusreg = 3 if statefip == 37
replace censusreg = 3 if statefip == 45
replace censusreg = 3 if statefip == 51
replace censusreg = 3 if statefip == 54

replace censusreg = 3 if statefip == 1
replace censusreg = 3 if statefip == 21
replace censusreg = 3 if statefip == 28
replace censusreg = 3 if statefip == 47

replace censusreg = 3 if statefip == 5
replace censusreg = 3 if statefip == 22
replace censusreg = 3 if statefip == 40
replace censusreg = 3 if statefip == 48

replace censusreg = 4 if statefip == 4
replace censusreg = 4 if statefip == 8
replace censusreg = 4 if statefip == 16
replace censusreg = 4 if statefip == 30
replace censusreg = 4 if statefip == 32
replace censusreg = 4 if statefip == 35
replace censusreg = 4 if statefip == 49
replace censusreg = 4 if statefip == 56

replace censusreg = 4 if statefip == 2
replace censusreg = 4 if statefip == 6
replace censusreg = 4 if statefip == 15
replace censusreg = 4 if statefip == 41
replace censusreg = 4 if statefip == 53

label variable censusreg "Census Regional Division (1-4)"

label values censusdiv census9
label values censusreg census4
label value statefips fips

order censusdiv censusreg,after(statefip)


*****
*     State inflation indexing of minimum wages; relationship to federal minimum wage
*****

gen year = year(date)
gen quarter = quarter(date)

gen indexedwage = 0
label variable indexedwage "State minimum wage is inflation-indexed"
replace indexedwage = 1 if year == 2001 & statefip == 53
replace indexedwage = 1 if year == 2002 & statefip == 53
replace indexedwage = 1 if year == 2003 & statefip == 53
replace indexedwage = 1 if year == 2004 & statefip == 53
replace indexedwage = 1 if year == 2004 & statefip == 41
replace indexedwage = 1 if year == 2005 & statefip == 53
replace indexedwage = 1 if year == 2005 & statefip == 41
replace indexedwage = 1 if year == 2006 & statefip == 53
replace indexedwage = 1 if year == 2006 & statefip == 41
replace indexedwage = 1 if year == 2006 & statefip == 12
replace indexedwage = 1 if year == 2007 & statefip == 53
replace indexedwage = 1 if year == 2007 & statefip == 50
replace indexedwage = 1 if year == 2007 & statefip == 41
replace indexedwage = 1 if year == 2007 & statefip == 32
replace indexedwage = 1 if year == 2007 & statefip == 12
replace indexedwage = 1 if year == 2008 & statefip == 53
replace indexedwage = 1 if year == 2008 & statefip == 50
replace indexedwage = 1 if year == 2008 & statefip == 41
replace indexedwage = 1 if year == 2008 & statefip == 39
replace indexedwage = 1 if year == 2008 & statefip == 32
replace indexedwage = 1 if year == 2008 & statefip == 30
replace indexedwage = 1 if year == 2008 & statefip == 29
replace indexedwage = 1 if year == 2008 & statefip == 12
replace indexedwage = 1 if year == 2008 & statefip == 8
replace indexedwage = 1 if year == 2008 & statefip == 4
replace indexedwage = 1 if year == 2009 & statefip == 53
replace indexedwage = 1 if year == 2009 & statefip == 50
replace indexedwage = 1 if year == 2009 & statefip == 41
replace indexedwage = 1 if year == 2009 & statefip == 39
replace indexedwage = 1 if year == 2009 & statefip == 32
replace indexedwage = 1 if year == 2009 & statefip == 30
replace indexedwage = 1 if year == 2009 & statefip == 29
replace indexedwage = 1 if year == 2009 & statefip == 12
replace indexedwage = 1 if year == 2009 & statefip == 8
replace indexedwage = 1 if year == 2009 & statefip == 4
replace indexedwage = 1 if year == 2010 & statefip == 53
replace indexedwage = 1 if year == 2010 & statefip == 50
replace indexedwage = 1 if year == 2010 & statefip == 41
replace indexedwage = 1 if year == 2010 & statefip == 39
replace indexedwage = 1 if year == 2010 & statefip == 32
replace indexedwage = 1 if year == 2010 & statefip == 30
replace indexedwage = 1 if year == 2010 & statefip == 29
replace indexedwage = 1 if year == 2010 & statefip == 12
replace indexedwage = 1 if year == 2010 & statefip == 8
replace indexedwage = 1 if year == 2010 & statefip == 4
replace indexedwage = 1 if year == 2011 & statefip == 53
replace indexedwage = 1 if year == 2011 & statefip == 50
replace indexedwage = 1 if year == 2011 & statefip == 41
replace indexedwage = 1 if year == 2011 & statefip == 39
replace indexedwage = 1 if year == 2011 & statefip == 32
replace indexedwage = 1 if year == 2011 & statefip == 30
replace indexedwage = 1 if year == 2011 & statefip == 29
replace indexedwage = 1 if year == 2011 & statefip == 12
replace indexedwage = 1 if year == 2011 & statefip == 8
replace indexedwage = 1 if year == 2011 & statefip == 4

gen tempsuperfed = 0
replace tempsuperfed = 1 if mw > fedmw
egen eversuperfed = max(tempsuperfed) , by(state)
drop tempsuperfed
label variable eversuperfed "Equals one if state ever had superfederal minimum wage (zero o/w)"

label variable statefips "State (FIPS code)"
label variable censusdiv "Census Division (1-9)"
label variable censusreg "Census Region (1-4)"
label variable date "Date: daily in Stata format"
label variable mw "State nominal minimum wage value"
label variable fedmw "Federal nominal minimum wage value"
label variable year "Year"
label variable quarter "Quarter"

order statefips censusreg censusdiv year quarter date mw fedmw indexedwage eversuperfed

compress
save mw_state_daily , replace


*-------------------------------------*
*  PREPARE THREE PANELS OF STATE MW   *
*-------------------------------------*

* 1. As of March 12 annually by state (for use with the BDS)
* 2. As of the first date of each quarter
* 3. As of the first date of each month

use mw_state_daily , clear

drop if statefips == 0

keep if month(date) == 3 & day(date) == 12

label variable mw "State minimum wage value on March 12"
label variable fedmw "Federal minimum wage value on March 12"

drop quarter date

merge m:1 year using dollars2011_cpiu_annual
drop if _merge == 2
drop _merge

sort state year

gen realmw = mw * dol2011
gen realfedmw = fedmw * dol2011

label variable realmw "State real minimum wage on March 12 (dollars 2011)"
label variable realfedmw "Federal real minimum wage on March 12 (dollars 2011)"

drop dol2011
gen lnmin = ln(realmw)
label variable lnmin "Log of state real minimum wage on March 12 (dollars 2011)"

order statefips censusreg censusdiv year lnmin realmw mw realfedmw fedmw indexedwage eversuperfed
compress

save mw_state_annual_march12 , replace // Annual as of March 12

*
* 2. by quarter
*

use mw_state_daily , clear

drop if statefips == 0

keep if month(date) == 1 | month(date) == 4 | month(date) == 7 | month(date) == 10
keep if day(date) == 1

label variable mw "State minimum wage value at start of quarter"
label variable fedmw "Federal minimum wage value at start of quarter"

drop date

merge m:1 year quarter using dollars2011_cpiu_quarterly
drop if _merge == 2
drop _merge

sort state year quarter

gen realmw = mw * dol2011
gen realfedmw = fedmw * dol2011

label variable realmw "State real minimum wage at start of quarter (dollars 2011)"
label variable realfedmw "Federal real minimum wage at start of quarter (dollars 2011)"

drop dol2011
gen lnmin = ln(realmw)
label variable lnmin "Log of state real minimum wage at start of quarter (dollars 2011)"

order statefips censusreg censusdiv year quarter lnmin realmw mw realfedmw fedmw indexedwage eversuperfed
compress

save mw_state_quarterly , replace // Quarterly as of first date of each quarter 

*
* 3. by month
*

use mw_state_daily , clear

drop if statefips == 0

keep if day(date) == 1

gen month = month(date)

label variable mw "State minimum wage value at start of month"
label variable fedmw "Federal minimum wage value at start of month"
label variable month "Month"

drop date

merge m:1 year month using dollars2011_cpiu_monthly
drop if _merge == 2
drop _merge

sort state year month

gen realmw = mw * dol2011
gen realfedmw = fedmw * dol2011

label variable realmw "State real minimum wage at start of month (dollars 2011)"
label variable realfedmw "Federal real minimum wage at start of month (dollars 2011)"

drop dol2011
gen lnmin = ln(realmw)
label variable lnmin "Log of state real minimum wage at start of month (dollars 2011)"

order statefips censusreg censusdiv year quarter month lnmin realmw mw realfedmw fedmw indexedwage eversuperfed
compress

save mw_state_monthly , replace // Monthly as of first date of each month
