/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

dollars2011_cpiu_quarterly.dta - Quarterly CPI values

mw_state_quarterly.dta - State minimum wage values as of first of each quarter

population_state_annual.dta - Annual state population

gsp_state_annual.dta - Annual gross state product

unemprt_state_quarterly.dta - Quarterly state unemployment rates

QWI:  multiple, by state; pattern is qwi_`state'_wia_wib_naics3_all.csv - from Census Bureau (hosted at Cornell)

NOTE: See the DataSources.txt file for more information


*/

*--------------------*
*        QWI         *
*--------------------*

*******************************
program define qwi

keep if sex == 0 & ownercode == "A00" // Both genders (combined) and all ownership types (combined)

* Change to "A05" is using the private sector "_pri_" files instead

gen industry = floor(naics3/10)

label values industry indlab

replace industry = 10 if naics3 == 0 // All subsectors (combined)
replace industry = 31 if industry == 32 | industry == 33
replace industry = 44 if industry == 45
replace industry = 48 if industry == 49

replace agegrp = subinstr(agegrp, "A", "", .)
destring agegrp , force replace

drop if agegrp !=0 & industry != 10 // Drop disaggregate age group categories for disaggregate industries

drop if emp == . // Missing data on employment level

label values agegrp agelab

rename state statefips
label values statefips fips

tostring wib , force replace
replace wib = "0" if wib == "00000000"
keep if wib == "0"
drop wib

collapse (sum) emp hira sep payroll , by(statefips industry year quarter agegrp)

order statefips industry agegrp year quarter emp hira sep payroll
sort statefips industry agegrp year quarter

compress

end
*******************************

* Change to "_pri.csv" if using the private sector files

insheet using qwi_al_wia_wib_naics3_all.csv , clear delimit(",")

qwi

save qwi , replace

foreach st in ak az ar ca co ct de ga hi id il in ia fl ks ky la me md mi mn ms mo ///
mt ne nv nh nj nm ny nc nd oh ok or pa ri sc sd tn tx ut vt va wa wv wi wy {

* Change to "_pri.csv" if using the private sector files

insheet using qwi_`st'_wia_wib_naics3_all.csv , clear delimit(",")

qwi

append using qwi

save qwi , replace

display "`st' done"
}

****

use qwi , clear

merge m:1 state year quarter using mw_state_quarterly
keep if _merge == 3
drop _merge

merge m:1 statefips year using population_state_annual
keep if _merge == 3
drop _merge

merge m:1 statefips year using gsp_state_annual
keep if _merge == 3
drop _merge

merge m:1 statefips year quarter using unemprt_state_quarterly
keep if _merge == 3
drop _merge

gen quarterly = yq(year, quarter)

sort statefips industry agegrp quarterly

egen stindagegp = group(statefips industry agegrp)
order stindagegp
label variable stindagegp "State X Industry X age group identifier"
 
xtset stindagegp quarterly
rename hira jc
rename sep jd

gen lemp = ln(emp)
gen jgr = (emp-l.emp) / (0.5 * l.emp + 0.5 * emp)
gen ljc = ln(jc)
gen ljd = ln(jd)

merge m:1 year quarter using dollars2011_cpiu_quarterly
drop if _merge == 2
drop _merge

replace payroll = payroll * dol2011 / 1000000

gen avgwage = payroll / emp * 1000000

drop dol2011

gen lavgwage = ln(avgwage)

order stindagegp statefips censusreg censusdiv industry agegrp quarterly year quarter emp lemp ///
jgr jc ljc jd ljd lnmin realmw mw realfedmw fedmw indexedwage eversuperfed payroll avgwage lavgwage ///
popall lpopall share1559 gsp rgsp rgspcap lrgspcap unemprt unem laborforce

label variable state "State"
label variable industry "Industry (2-digit NAICS)"
label variable agegrp "Age group (only for all industries combined)"
label variable year "Year"
label variable quarter "Quarter"
label variable quarterly "Quarterly indicator (Stata format)"
label variable emp "Quarterly average employment"
label variable payroll "Quarterly total payroll (millions 2011)"
label variable avgwage "Quarterly average wage (dollars 2011)"
label variable lemp "Log of employment"
label variable jgr "Job growth rate"
label variable ljc "Log of job creation"
label variable ljd "Log of job destruction"
label variable lavgwage "Log of quarterly average wage (dollars 2011)"

sort statefips industry agegrp quarterly

compress
save qwi , replace
